@@ -87,10 +87,11 @@ class Poisson(Noise):
 
     def get(self, image, snr, background, **kwargs):
         image[image < 0] = 0
-
-        peak = np.abs(np.max(image) - background)
+        immax = np.max(image)
+        peak = np.abs(immax - background)
 
         rescale = snr ** 2 / peak ** 2
+        rescale = np.clip(rescale, 1e-10, np.inf)
         noisy_image = Image(np.random.poisson(image * rescale) / rescale)
         noisy_image.properties = image.properties
         return noisy_image
